# Generated by Django 4.2.5 on 2023-10-02 05:36

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0187_auto_20230926_1627'),
    ]

    operations = [
        migrations.AlterField(
            model_name='learnercreditenterprisecourseenrollment',
            name='enterprise_course_enrollment',
            field=models.OneToOneField(blank=True, help_text='The course enrollment the associated subsidy is for.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='%(class)s_enrollment_fulfillment', to='enterprise.enterprisecourseenrollment'),
        ),
        migrations.AlterField(
            model_name='learnercreditenterprisecourseenrollment',
            name='enterprise_course_entitlement',
            field=models.OneToOneField(blank=True, help_text='The course entitlement the associated subsidy is for.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='%(class)s_entitlement_fulfillment', to='enterprise.enterprisecourseentitlement'),
        ),
        migrations.AlterField(
            model_name='licensedenterprisecourseenrollment',
            name='enterprise_course_enrollment',
            field=models.OneToOneField(blank=True, help_text='The course enrollment the associated subsidy is for.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='%(class)s_enrollment_fulfillment', to='enterprise.enterprisecourseenrollment'),
        ),
        migrations.AlterField(
            model_name='licensedenterprisecourseenrollment',
            name='enterprise_course_entitlement',
            field=models.OneToOneField(blank=True, help_text='The course entitlement the associated subsidy is for.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='%(class)s_entitlement_fulfillment', to='enterprise.enterprisecourseentitlement'),
        ),
    ]
