# Generated by Django 3.2.23 on 2024-04-08 13:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0205_auto_20240408_1117'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisegroupmembership',
            name='removed_at',
            field=models.DateTimeField(blank=True, default=None, help_text='The moment at which the membership record was revoked by an Enterprise admin.', null=True),
        ),
        migrations.AddField(
            model_name='enterprisegroupmembership',
            name='status',
            field=models.CharField(blank=True, choices=[('removed', 'Removed'), ('accepted', 'Accepted'), ('pending', 'Pending')], default='pending', help_text='Current status of the membership record', max_length=20, null=True, verbose_name='Membership Status'),
        ),
        migrations.AddField(
            model_name='historicalenterprisegroupmembership',
            name='removed_at',
            field=models.DateTimeField(blank=True, default=None, help_text='The moment at which the membership record was revoked by an Enterprise admin.', null=True),
        ),
        migrations.AddField(
            model_name='historicalenterprisegroupmembership',
            name='status',
            field=models.CharField(blank=True, choices=[('removed', 'Removed'), ('accepted', 'Accepted'), ('pending', 'Pending')], default='pending', help_text='Current status of the membership record', max_length=20, null=True, verbose_name='Membership Status'),
        ),
    ]
