# Generated by Django 3.2.23 on 2024-04-08 07:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0203_auto_20240312_1527'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_one_academy',
            field=models.BooleanField(default=False, help_text='If checked, search will be replaced with one academy on enterprise learner portal.', verbose_name='Enable One Academy feature'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_one_academy',
            field=models.BooleanField(default=False, help_text='If checked, search will be replaced with one academy on enterprise learner portal.', verbose_name='Enable One Academy feature'),
        ),
    ]
